@@ -13,7 +13,6 @@
  *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  *  See the License for the specific language governing permissions and
  *  limitations under the License.
- *
  */
 package org.apache.bcel.generic;
 
@@ -25,15 +24,14 @@ import org.apache.bcel.util.ByteSequence;
 /**
  * Select - Abstract super class for LOOKUPSWITCH and TABLESWITCH instructions.
  *
- * <p>We use our super's <code>target</code> property as the default target.
+ * <p>
+ * We use our super's {@code target} property as the default target.
  *
- * @version $Id: Select.java 1806200 2017-08-25 16:33:06Z ggregory $
  * @see LOOKUPSWITCH
  * @see TABLESWITCH
  * @see InstructionList
  */
-public abstract class Select extends BranchInstruction implements VariableLengthInstruction,
-        StackConsumer /* @since 6.0 */, StackProducer {
+public abstract class Select extends BranchInstruction implements VariableLengthInstruction, StackConsumer /* @since 6.0 */, StackProducer {
 
     /**
      * @deprecated (since 6.0) will be made private; do not access directly, use getter/setter
@@ -69,20 +67,16 @@ public abstract class Select extends BranchInstruction implements VariableLength
      * @deprecated (since 6.0) will be made private; do not access directly, use getter/setter
      */
     @Deprecated
-    protected int padding = 0; // number of pad bytes for alignment TODO could be package-protected?
-
+    protected int padding; // number of pad bytes for alignment TODO could be package-protected?
 
     /**
-     * Empty constructor needed for the Class.newInstance() statement in
-     * Instruction.readInstruction(). Not to be used otherwise.
+     * Empty constructor needed for Instruction.readInstruction. Not to be used otherwise.
      */
     Select() {
     }
 
-
     /**
-     * (Match, target) pairs for switch.
-     * `Match' and `targets' must have the same length of course.
+     * (Match, target) pairs for switch. 'Match' and 'targets' must have the same length of course.
      *
      * @param match array of matching values
      * @param targets instruction targets
@@ -99,138 +93,11 @@ public abstract class Select extends BranchInstruction implements VariableLength
             notifyTarget(null, target2, this);
         }
         if ((match_length = match.length) != targets.length) {
-            throw new ClassGenException("Match and target array have not the same length: Match length: " +
-                match.length + " Target length: " + targets.length);
+            throw new ClassGenException("Match and target array have not the same length: Match length: " + match.length + " Target length: " + targets.length);
         }
         indices = new int[match_length];
     }
 
-
-    /**
-     * Since this is a variable length instruction, it may shift the following
-     * instructions which then need to update their position.
-     *
-     * Called by InstructionList.setPositions when setting the position for every
-     * instruction. In the presence of variable length instructions `setPositions'
-     * performs multiple passes over the instruction list to calculate the
-     * correct (byte) positions and offsets by calling this function.
-     *
-     * @param offset additional offset caused by preceding (variable length) instructions
-     * @param max_offset the maximum offset that may be caused by these instructions
-     * @return additional offset caused by possible change of this instruction's length
-     */
-    @Override
-    protected int updatePosition( final int offset, final int max_offset ) {
-        setPosition(getPosition() + offset); // Additional offset caused by preceding SWITCHs, GOTOs, etc.
-        final short old_length = (short) super.getLength();
-        /* Alignment on 4-byte-boundary, + 1, because of tag byte.
-         */
-        padding = (4 - ((getPosition() + 1) % 4)) % 4;
-        super.setLength((short) (fixed_length + padding)); // Update length
-        return super.getLength() - old_length;
-    }
-
-
-    /**
-     * Dump instruction as byte code to stream out.
-     * @param out Output stream
-     */
-    @Override
-    public void dump( final DataOutputStream out ) throws IOException {
-        out.writeByte(super.getOpcode());
-        for (int i = 0; i < padding; i++) {
-            out.writeByte(0);
-        }
-        super.setIndex(getTargetOffset()); // Write default target offset
-        out.writeInt(super.getIndex());
-    }
-
-
-    /**
-     * Read needed data (e.g. index) from file.
-     */
-    @Override
-    protected void initFromFile( final ByteSequence bytes, final boolean wide ) throws IOException {
-        padding = (4 - (bytes.getIndex() % 4)) % 4; // Compute number of pad bytes
-        for (int i = 0; i < padding; i++) {
-            bytes.readByte();
-        }
-        // Default branch target common for both cases (TABLESWITCH, LOOKUPSWITCH)
-        super.setIndex(bytes.readInt());
-    }
-
-
-    /**
-     * @return mnemonic for instruction
-     */
-    @Override
-    public String toString( final boolean verbose ) {
-        final StringBuilder buf = new StringBuilder(super.toString(verbose));
-        if (verbose) {
-            for (int i = 0; i < match_length; i++) {
-                String s = "null";
-                if (targets[i] != null) {
-                    s = targets[i].getInstruction().toString();
-                }
-                buf.append("(").append(match[i]).append(", ").append(s).append(" = {").append(
-                        indices[i]).append("})");
-            }
-        } else {
-            buf.append(" ...");
-        }
-        return buf.toString();
-    }
-
-
-    /**
-     * Set branch target for `i'th case
-     */
-    public void setTarget( final int i, final InstructionHandle target ) { // TODO could be package-protected?
-        notifyTarget(targets[i], target, this);
-        targets[i] = target;
-    }
-
-
-    /**
-     * @param old_ih old target
-     * @param new_ih new target
-     */
-    @Override
-    public void updateTarget( final InstructionHandle old_ih, final InstructionHandle new_ih ) {
-        boolean targeted = false;
-        if (super.getTarget() == old_ih) {
-            targeted = true;
-            setTarget(new_ih);
-        }
-        for (int i = 0; i < targets.length; i++) {
-            if (targets[i] == old_ih) {
-                targeted = true;
-                setTarget(i, new_ih);
-            }
-        }
-        if (!targeted) {
-            throw new ClassGenException("Not targeting " + old_ih);
-        }
-    }
-
-
-    /**
-     * @return true, if ih is target of this instruction
-     */
-    @Override
-    public boolean containsTarget( final InstructionHandle ih ) {
-        if (super.getTarget() == ih) {
-            return true;
-        }
-        for (final InstructionHandle target2 : targets) {
-            if (target2 == ih) {
-                return true;
-            }
-        }
-        return false;
-    }
-
-
     @Override
     protected Object clone() throws CloneNotSupportedException {
         final Select copy = (Select) super.clone();
@@ -240,6 +107,21 @@ public abstract class Select extends BranchInstruction implements VariableLength
         return copy;
     }
 
+    /**
+     * @return true, if ih is target of this instruction
+     */
+    @Override
+    public boolean containsTarget(final InstructionHandle ih) {
+        if (super.getTarget() == ih) {
+            return true;
+        }
+        for (final InstructionHandle target2 : targets) {
+            if (target2 == ih) {
+                return true;
+            }
+        }
+        return false;
+    }
 
     /**
      * Inform targets that they're not targeted anymore.
@@ -252,14 +134,28 @@ public abstract class Select extends BranchInstruction implements VariableLength
         }
     }
 
-
     /**
-     * @return array of match indices
+     * Dump instruction as byte code to stream out.
+     *
+     * @param out Output stream
      */
-    public int[] getMatchs() {
-        return match;
+    @Override
+    public void dump(final DataOutputStream out) throws IOException {
+        out.writeByte(super.getOpcode());
+        for (int i = 0; i < padding; i++) {
+            out.writeByte(0);
+        }
+        super.setIndex(getTargetOffset()); // Write default target offset
+        out.writeInt(super.getIndex());
     }
 
+    /**
+     * @return the fixed_length
+     * @since 6.0
+     */
+    final int getFixedLength() {
+        return fixed_length;
+    }
 
     /**
      * @return array of match target offsets
@@ -268,23 +164,6 @@ public abstract class Select extends BranchInstruction implements VariableLength
         return indices;
     }
 
-
-    /**
-     * @return array of match targets
-     */
-    public InstructionHandle[] getTargets() {
-        return targets;
-    }
-
-    /**
-     * @return match entry
-     * @since 6.0
-     */
-    final int getMatch(final int index) {
-        return match[index];
-    }
-
-
     /**
      * @return index entry from indices
      * @since 6.0
@@ -293,6 +172,38 @@ public abstract class Select extends BranchInstruction implements VariableLength
         return indices[index];
     }
 
+    /**
+     * @return match entry
+     * @since 6.0
+     */
+    final int getMatch(final int index) {
+        return match[index];
+    }
+
+    /**
+     * @return the match_length
+     * @since 6.0
+     */
+    final int getMatchLength() {
+        return match_length;
+    }
+
+    /**
+     * @return array of match indices
+     */
+    public int[] getMatchs() {
+        return match;
+    }
+
+    /**
+     *
+     * @return the padding
+     * @since 6.0
+     */
+    final int getPadding() {
+        return padding;
+    }
+
     /**
      * @return target entry
      * @since 6.0
@@ -301,41 +212,47 @@ public abstract class Select extends BranchInstruction implements VariableLength
         return targets[index];
     }
 
-
     /**
-     * @return the fixed_length
-     * @since 6.0
+     * @return array of match targets
      */
-    final int getFixed_length() {
-        return fixed_length;
+    public InstructionHandle[] getTargets() {
+        return targets;
     }
 
-
     /**
-     * @param fixed_length the fixed_length to set
-     * @since 6.0
+     * Read needed data (e.g. index) from file.
      */
-    final void setFixed_length(final int fixed_length) {
-        this.fixed_length = fixed_length;
+    @Override
+    protected void initFromFile(final ByteSequence bytes, final boolean wide) throws IOException {
+        padding = (4 - bytes.getIndex() % 4) % 4; // Compute number of pad bytes
+        for (int i = 0; i < padding; i++) {
+            bytes.readByte();
+        }
+        // Default branch target common for both cases (TABLESWITCH, LOOKUPSWITCH)
+        super.setIndex(bytes.readInt());
     }
 
-
     /**
-     * @return the match_length
+     * @param fixedLength the fixed_length to set
      * @since 6.0
      */
-    final int getMatch_length() {
-        return match_length;
+    final void setFixedLength(final int fixedLength) {
+        this.fixed_length = fixedLength;
     }
 
+    /** @since 6.0 */
+    final int setIndices(final int i, final int value) {
+        indices[i] = value;
+        return value; // Allow use in nested calls
+    }
 
     /**
-     * @param match_length the match_length to set
+     *
+     * @param array
      * @since 6.0
      */
-    final int setMatch_length(final int match_length) {
-        this.match_length = match_length;
-        return match_length;
+    final void setIndices(final int[] array) {
+        indices = array;
     }
 
     /**
@@ -353,17 +270,25 @@ public abstract class Select extends BranchInstruction implements VariableLength
      * @param array
      * @since 6.0
      */
-    final void setIndices(final int[] array) {
-        indices = array;
+    final void setMatches(final int[] array) {
+        match = array;
     }
 
     /**
-     *
-     * @param array
+     * @param matchLength the match_length to set
      * @since 6.0
      */
-    final void setMatches(final int[] array) {
-        match = array;
+    final int setMatchLength(final int matchLength) {
+        this.match_length = matchLength;
+        return matchLength;
+    }
+
+    /**
+     * Set branch target for 'i'th case
+     */
+    public void setTarget(final int i, final InstructionHandle target) { // TODO could be package-protected?
+        notifyTarget(targets[i], target, this);
+        targets[i] = target;
     }
 
     /**
@@ -376,18 +301,68 @@ public abstract class Select extends BranchInstruction implements VariableLength
     }
 
     /**
-     *
-     * @return the padding
-     * @since 6.0
+     * @return mnemonic for instruction
      */
-    final int getPadding() {
-        return padding;
+    @Override
+    public String toString(final boolean verbose) {
+        final StringBuilder buf = new StringBuilder(super.toString(verbose));
+        if (verbose) {
+            for (int i = 0; i < match_length; i++) {
+                String s = "null";
+                if (targets[i] != null) {
+                    s = targets[i].getInstruction().toString();
+                }
+                buf.append("(").append(match[i]).append(", ").append(s).append(" = {").append(indices[i]).append("})");
+            }
+        } else {
+            buf.append(" ...");
+        }
+        return buf.toString();
     }
 
+    /**
+     * Since this is a variable length instruction, it may shift the following instructions which then need to update their
+     * position.
+     *
+     * Called by InstructionList.setPositions when setting the position for every instruction. In the presence of variable
+     * length instructions 'setPositions' performs multiple passes over the instruction list to calculate the correct (byte)
+     * positions and offsets by calling this function.
+     *
+     * @param offset additional offset caused by preceding (variable length) instructions
+     * @param maxOffset the maximum offset that may be caused by these instructions
+     * @return additional offset caused by possible change of this instruction's length
+     */
+    @Override
+    protected int updatePosition(final int offset, final int maxOffset) {
+        setPosition(getPosition() + offset); // Additional offset caused by preceding SWITCHs, GOTOs, etc.
+        final short oldLength = (short) super.getLength();
+        /*
+         * Alignment on 4-byte-boundary, + 1, because of tag byte.
+         */
+        padding = (4 - (getPosition() + 1) % 4) % 4;
+        super.setLength((short) (fixed_length + padding)); // Update length
+        return super.getLength() - oldLength;
+    }
 
-    /** @since 6.0 */
-    final int setIndices(final int i, final int value) {
-        indices[i] = value;
-        return value;  // Allow use in nested calls
+    /**
+     * @param oldIh old target
+     * @param newIh new target
+     */
+    @Override
+    public void updateTarget(final InstructionHandle oldIh, final InstructionHandle newIh) {
+        boolean targeted = false;
+        if (super.getTarget() == oldIh) {
+            targeted = true;
+            setTarget(newIh);
+        }
+        for (int i = 0; i < targets.length; i++) {
+            if (targets[i] == oldIh) {
+                targeted = true;
+                setTarget(i, newIh);
+            }
+        }
+        if (!targeted) {
+            throw new ClassGenException("Not targeting " + oldIh);
+        }
     }
 }
